@@ -101,6 +101,7 @@ def mollview(
     nlocs=2,
     return_projected_map=False,
     alpha=None,
+    fontsize=None,
 ):
     """Plot a healpix map (given as an array) in Mollweide projection.
 
@@ -180,6 +181,12 @@ def mollview(
     alpha : float, array-like or None
       An array containing the alpha channel, supports masked maps, see the `ma` function.
       If None, no transparency will be applied.
+    fontsize : dict, optional
+      Override font sizes. Allowed keys are 'xlabel', 'ylabel', 'title', 'xtick_label', 
+      'ytick_label', 'cbar_label', 'cbar_tick_label'. Default: None uses relative sizes
+      that scale with DPI ('large' for most text). To exactly reproduce plots from 
+      previous versions, use: ``fontsize={'xlabel': 14, 'ylabel': 14, 'title': 14, 
+      'cbar_label': 14}``
 
     See Also
     --------
@@ -196,6 +203,22 @@ def mollview(
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
+    # Set up font sizes - use provided values or defaults
+    if fontsize is None:
+        fontsize = {}
+    fontsize_defaults = {
+        'xlabel': 'large',
+        'ylabel': 'large', 
+        'title': 'large',
+        'xtick_label': 'large',
+        'ytick_label': 'large',
+        'cbar_label': 'large',
+        'cbar_tick_label': 'large',
+    }
+    for key in fontsize_defaults:
+        if key not in fontsize:
+            fontsize[key] = fontsize_defaults[key]
+
     if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         if not margins:
@@ -308,12 +331,13 @@ def mollview(
                 )
             cb.solids.set_rasterized(True)
         ax.set_title(title)
-        if not notext:
+        coordsys_label = ax.proj.coordsysstr
+        if not notext and coordsys_label:
             ax.text(
                 0.86,
                 0.05,
-                ax.proj.coordsysstr,
-                fontsize=14,
+                coordsys_label,
+                fontsize=fontsize['cbar_label'],
                 fontweight="bold",
                 transform=ax.transAxes,
             )
@@ -322,7 +346,7 @@ def mollview(
                 0.5,
                 -1.0,
                 unit,
-                fontsize=14,
+                fontsize=fontsize['cbar_label'],
                 transform=cb.ax.transAxes,
                 ha="center",
                 va="center",
@@ -368,6 +392,7 @@ def gnomview(
     return_projected_map=False,
     no_plot=False,
     alpha=None,
+    fontsize=None,
 ):
     """Plot a healpix map (given as an array) in Gnomonic projection.
 
@@ -449,6 +474,12 @@ def gnomview(
       If None, no transparency will be applied.
       See an example usage of the alpha channel transparency in the documentation under
       "Other tutorials"
+    fontsize : dict, optional
+      Override font sizes. Allowed keys are 'xlabel', 'ylabel', 'title', 'xtick_label', 
+      'ytick_label', 'cbar_label', 'cbar_tick_label'. Default: None uses relative sizes
+      that scale with DPI ('large' for most text, 'medium' for resolution info). 
+      To exactly reproduce plots from previous versions, use: 
+      ``fontsize={'cbar_label': 14, 'xtick_label': 12}``
 
     See Also
     --------
@@ -464,6 +495,22 @@ def gnomview(
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
+    # Set up font sizes - use provided values or defaults
+    if fontsize is None:
+        fontsize = {}
+    fontsize_defaults = {
+        'xlabel': 'large',
+        'ylabel': 'large', 
+        'title': 'large',
+        'xtick_label': 'medium',  # resolution info text
+        'ytick_label': 'large',
+        'cbar_label': 'large',
+        'cbar_tick_label': 'large',
+    }
+    for key in fontsize_defaults:
+        if key not in fontsize:
+            fontsize[key] = fontsize_defaults[key]
+
     if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(5.8, 6.4))
         if not margins:
@@ -582,20 +629,22 @@ def gnomview(
                     ax.proj.arrayinfo["xsize"],
                     ax.proj.arrayinfo["ysize"],
                 ),
-                fontsize=12,
+                fontsize=fontsize['xtick_label'],
                 verticalalignment="bottom",
                 transform=ax.transAxes,
                 rotation=90,
             )
-            ax.text(
-                -0.07,
-                0.6,
-                ax.proj.coordsysstr,
-                fontsize=14,
-                fontweight="bold",
-                rotation=90,
-                transform=ax.transAxes,
-            )
+            coordsys_label = ax.proj.coordsysstr
+            if coordsys_label:
+                ax.text(
+                    -0.07,
+                    0.6,
+                    coordsys_label,
+                    fontsize=fontsize['cbar_label'],
+                    fontweight="bold",
+                    rotation=90,
+                    transform=ax.transAxes,
+                )
             lon, lat = np.around(ax.proj.get_center(lonlat=True), ax._coordprec)
             ax.text(
                 0.5,
@@ -610,7 +659,7 @@ def gnomview(
                 1.05,
                 0.30,
                 unit,
-                fontsize=14,
+                fontsize=fontsize['cbar_label'],
                 fontweight="bold",
                 transform=cb.ax.transAxes,
                 ha="left",
@@ -663,6 +712,7 @@ def cartview(
     notext=False,
     return_projected_map=False,
     alpha=None,
+    fontsize=None,
 ):
     """Plot a healpix map (given as an array) in Cartesian projection.
 
@@ -745,6 +795,11 @@ def cartview(
     alpha : float, array-like or None
       An array containing the alpha channel, supports masked maps, see the `ma` function.
       If None, no transparency will be applied.
+    fontsize : dict, optional
+      Override font sizes. Allowed keys are 'xlabel', 'ylabel', 'title', 'xtick_label', 
+      'ytick_label', 'cbar_label', 'cbar_tick_label'. Default: None uses relative sizes
+      that scale with DPI ('large' for most text). To exactly reproduce plots from 
+      previous versions, use: ``fontsize={'cbar_label': 14}``
 
     See Also
     --------
@@ -760,6 +815,22 @@ def cartview(
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
+    # Set up font sizes - use provided values or defaults
+    if fontsize is None:
+        fontsize = {}
+    fontsize_defaults = {
+        'xlabel': 'large',
+        'ylabel': 'large', 
+        'title': 'large',
+        'xtick_label': 'large',
+        'ytick_label': 'large',
+        'cbar_label': 'large',
+        'cbar_tick_label': 'large',
+    }
+    for key in fontsize_defaults:
+        if key not in fontsize:
+            fontsize[key] = fontsize_defaults[key]
+
     if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         if not margins:
@@ -876,12 +947,13 @@ def cartview(
                 )
             cb.solids.set_rasterized(True)
         ax.set_title(title)
-        if not notext:
+        coordsys_label = ax.proj.coordsysstr
+        if not notext and coordsys_label:
             ax.text(
                 -0.07,
                 0.6,
-                ax.proj.coordsysstr,
-                fontsize=14,
+                coordsys_label,
+                fontsize=fontsize['cbar_label'],
                 fontweight="bold",
                 rotation=90,
                 transform=ax.transAxes,
@@ -891,7 +963,7 @@ def cartview(
                 1.05,
                 0.30,
                 unit,
-                fontsize=14,
+                fontsize=fontsize['cbar_label'],
                 fontweight="bold",
                 transform=cb.ax.transAxes,
                 ha="left",
@@ -937,6 +1009,7 @@ def orthview(
     reuse_axes=False,
     return_projected_map=False,
     alpha=None,
+    fontsize=None,
 ):
     """Plot a healpix map (given as an array) in Orthographic projection.
 
@@ -1018,6 +1091,11 @@ def orthview(
     alpha : float, array-like or None
       An array containing the alpha channel, supports masked maps, see the `ma` function.
       If None, no transparency will be applied.
+    fontsize : dict, optional
+      Override font sizes. Allowed keys are 'xlabel', 'ylabel', 'title', 'xtick_label', 
+      'ytick_label', 'cbar_label', 'cbar_tick_label'. Default: None uses relative sizes
+      that scale with DPI ('large' for most text). To exactly reproduce plots from 
+      previous versions, use: ``fontsize={'cbar_label': 14}``
 
     See Also
     --------
@@ -1034,6 +1112,22 @@ def orthview(
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
+    # Set up font sizes - use provided values or defaults
+    if fontsize is None:
+        fontsize = {}
+    fontsize_defaults = {
+        'xlabel': 'large',
+        'ylabel': 'large', 
+        'title': 'large',
+        'xtick_label': 'large',
+        'ytick_label': 'large',
+        'cbar_label': 'large',
+        'cbar_tick_label': 'large',
+    }
+    for key in fontsize_defaults:
+        if key not in fontsize:
+            fontsize[key] = fontsize_defaults[key]
+
     if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         if not margins:
@@ -1144,12 +1238,13 @@ def orthview(
                 )
             cb.solids.set_rasterized(True)
         ax.set_title(title)
-        if not notext:
+        coordsys_label = ax.proj.coordsysstr
+        if not notext and coordsys_label:
             ax.text(
                 0.86,
                 0.05,
-                ax.proj.coordsysstr,
-                fontsize=14,
+                coordsys_label,
+                fontsize=fontsize['cbar_label'],
                 fontweight="bold",
                 transform=ax.transAxes,
             )
@@ -1158,7 +1253,7 @@ def orthview(
                 0.5,
                 -1.0,
                 unit,
-                fontsize=14,
+                fontsize=fontsize['cbar_label'],
                 transform=cb.ax.transAxes,
                 ha="center",
                 va="center",
@@ -1207,6 +1302,7 @@ def azeqview(
     notext=False,
     return_projected_map=False,
     alpha=None,
+    fontsize=None,
 ):
     """Plot a healpix map (given as an array) in Azimuthal equidistant projection
     or Lambert azimuthal equal-area projection.
@@ -1296,6 +1392,11 @@ def azeqview(
     alpha : float, array-like or None
       An array containing the alpha channel, supports masked maps, see the `ma` function.
       If None, no transparency will be applied.
+    fontsize : dict, optional
+      Override font sizes. Allowed keys are 'xlabel', 'ylabel', 'title', 'xtick_label', 
+      'ytick_label', 'cbar_label', 'cbar_tick_label'. Default: None uses relative sizes
+      that scale with DPI ('large' for most text). To exactly reproduce plots from 
+      previous versions, use: ``fontsize={'cbar_label': 14}``
 
     See Also
     --------
@@ -1312,6 +1413,22 @@ def azeqview(
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
+    # Set up font sizes - use provided values or defaults
+    if fontsize is None:
+        fontsize = {}
+    fontsize_defaults = {
+        'xlabel': 'large',
+        'ylabel': 'large', 
+        'title': 'large',
+        'xtick_label': 'large',
+        'ytick_label': 'large',
+        'cbar_label': 'large',
+        'cbar_tick_label': 'large',
+    }
+    for key in fontsize_defaults:
+        if key not in fontsize:
+            fontsize[key] = fontsize_defaults[key]
+
     if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         if not margins:
@@ -1430,12 +1547,13 @@ def azeqview(
             else:
                 title = "Azimuthal equidistant view"
         ax.set_title(title)
-        if not notext:
+        coordsys_label = ax.proj.coordsysstr
+        if not notext and coordsys_label:
             ax.text(
                 0.86,
                 0.05,
-                ax.proj.coordsysstr,
-                fontsize=14,
+                coordsys_label,
+                fontsize=fontsize['cbar_label'],
                 fontweight="bold",
                 transform=ax.transAxes,
             )
@@ -1444,7 +1562,7 @@ def azeqview(
                 0.5,
                 -1.0,
                 unit,
-                fontsize=14,
+                fontsize=fontsize['cbar_label'],
                 transform=cb.ax.transAxes,
                 ha="center",
                 va="center",
@@ -1459,7 +1577,7 @@ def azeqview(
         return img
 
 
-def graticule(dpar=None, dmer=None, coord=None, local=None, **kwds):
+def graticule(dpar=None, dmer=None, coord=None, local=None, fontsize=None, **kwds):
     """Draw a graticule on the current Axes.
 
     Parameters
@@ -1473,6 +1591,9 @@ def graticule(dpar=None, dmer=None, coord=None, local=None, **kwds):
     local : bool
       If True, draw a local graticule (no rotation is performed, useful for
       a gnomonic view, for example)
+    fontsize : float or str, optional
+      Font size for coordinate system label. Default: 'large' (scales with DPI).
+      To exactly reproduce plots from previous versions, use: ``fontsize=14``
 
     Notes
     -----
@@ -1484,6 +1605,9 @@ def graticule(dpar=None, dmer=None, coord=None, local=None, **kwds):
     """
     import pylab
 
+    if fontsize is None:
+        fontsize = 'large'
+
     f = pylab.gcf()
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
@@ -1491,14 +1615,16 @@ def graticule(dpar=None, dmer=None, coord=None, local=None, **kwds):
         if len(f.get_axes()) == 0:
             ax = PA.HpxMollweideAxes(f, (0.02, 0.05, 0.96, 0.9), coord=coord)
             f.add_axes(ax)
-            ax.text(
-                0.86,
-                0.05,
-                ax.proj.coordsysstr,
-                fontsize=14,
-                fontweight="bold",
-                transform=ax.transAxes,
-            )
+            coordsys_label = ax.proj.coordsysstr
+            if coordsys_label:
+                ax.text(
+                    0.86,
+                    0.05,
+                    coordsys_label,
+                    fontsize=fontsize,
+                    fontweight="bold",
+                    transform=ax.transAxes,
+                )
         for ax in f.get_axes():
             if isinstance(ax, PA.SphericalProjAxes):
                 ax.graticule(dpar=dpar, dmer=dmer, coord=coord, local=local, **kwds)
@@ -1534,14 +1660,13 @@ def delgraticules():
 def projplot(*args, **kwds):
     import pylab
 
-    f = pylab.gcf()
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     ret = None
     try:
-        for ax in f.get_axes():
-            if isinstance(ax, PA.SphericalProjAxes):
-                ret = ax.projplot(*args, **kwds)
+        ax = pylab.gca()
+        if isinstance(ax, PA.SphericalProjAxes):
+            ret = ax.projplot(*args, **kwds)
     finally:
         pylab.draw()
         if wasinteractive:
@@ -1556,14 +1681,13 @@ projplot.__doc__ = PA.SphericalProjAxes.projplot.__doc__
 def projscatter(*args, **kwds):
     import pylab
 
-    f = pylab.gcf()
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     ret = None
     try:
-        for ax in f.get_axes():
-            if isinstance(ax, PA.SphericalProjAxes):
-                ret = ax.projscatter(*args, **kwds)
+        ax = pylab.gca()
+        if isinstance(ax, PA.SphericalProjAxes):
+            ret = ax.projscatter(*args, **kwds)
     finally:
         pylab.draw()
         if wasinteractive:
@@ -1578,14 +1702,13 @@ projscatter.__doc__ = PA.SphericalProjAxes.projscatter.__doc__
 def projtext(*args, **kwds):
     import pylab
 
-    f = pylab.gcf()
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     ret = None
     try:
-        for ax in f.get_axes():
-            if isinstance(ax, PA.SphericalProjAxes):
-                ret = ax.projtext(*args, **kwds)
+        ax = pylab.gca()
+        if isinstance(ax, PA.SphericalProjAxes):
+            ret = ax.projtext(*args, **kwds)
     finally:
         pylab.draw()
         if wasinteractive:
